@@ -4,32 +4,33 @@ from tests.fixtures.accounts import cp1
 from tests.fixtures.accounts import cp2
 from tests.fixtures.accounts import account_key
 from tests.fixtures.accounts import account_hash
-
 from tests.fixtures.chain import account_main_purse_uref
 from tests.fixtures.chain import block
 from tests.fixtures.chain import block_hash
 from tests.fixtures.chain import state_root_hash
 from tests.fixtures.chain import switch_block
 from tests.fixtures.chain import switch_block_hash
-
-from tests.fixtures.crypto import key_pair_specs
-
+from tests.fixtures.contracts import path_to_wasm_auction_bid
+from tests.fixtures.contracts import path_to_wasm_auction_bid_withdrawal
+from tests.fixtures.contracts import path_to_wasm_delegate
+from tests.fixtures.contracts import path_to_wasm_delegate_withdrawal
 from tests.fixtures.deploys import a_test_chain_id
+from tests.fixtures.deploys import a_test_timestamp
 from tests.fixtures.deploys import a_test_ttl_humanized
+from tests.fixtures.deploys import a_test_uref
 from tests.fixtures.deploys import deploy_params
 from tests.fixtures.deploys import deploy_params_static
 from tests.fixtures.deploys import a_deploy
-
 from tests.fixtures.node import CLIENT
 from tests.fixtures.node import NODE_HOST
 from tests.fixtures.node import NODE_PORT_REST
 from tests.fixtures.node import NODE_PORT_RPC
 from tests.fixtures.node import NODE_PORT_SSE
-
-from tests.fixtures.misc import a_test_timestamp
-
-from tests.fixtures.vectors import cl_types as vector_cl_types
-from tests.fixtures.vectors import crypto_1 as vector_crypto_1
-from tests.fixtures.vectors import crypto_2 as vector_crypto_2
-from tests.fixtures.vectors import crypto_3 as vector_crypto_3
-from tests.fixtures.vectors import deploy_1 as vector_deploy_1
+from tests.fixtures.vectors import cl_types as cl_types_vector
+from tests.fixtures.vectors import cl_values as cl_values_vector
+from tests.fixtures.vectors import crypto_checksums
+from tests.fixtures.vectors import crypto_hashes
+from tests.fixtures.vectors import crypto_key_pairs
+from tests.fixtures.vectors import crypto_key_pair_specs
+from tests.fixtures.vectors import crypto_signatures
+from tests.fixtures.vectors import deploys_1
