@@ -1,9 +1,11 @@
 import os
+import pathlib
 
 import pytest
 
 import pycspr
 
+_PATH_TO_NCTL_ASSETS = pathlib.Path(os.getenv("NCTL")) / "assets" / "net-1"
 
 
 @pytest.fixture(scope="session")
@@ -12,15 +14,13 @@ def CLIENT(
     NODE_PORT_REST,
     NODE_PORT_RPC,
     NODE_PORT_SSE
-    ) -> pycspr.NodeClient:
-    connection = pycspr.NodeConnectionInfo(
+) -> pycspr.NodeClient:
+    return pycspr.NodeClient(pycspr.NodeConnection(
         host=NODE_HOST,
         port_rest=NODE_PORT_REST,
         port_rpc=NODE_PORT_RPC,
         port_sse=NODE_PORT_SSE
-    )
-
-    return pycspr.NodeClient(connection)
+    ))
 
 
 @pytest.fixture(scope="session")
